# word_text_counter

Calculate word counts in a text file!

## Installation

```bash
$ pip install word_text_counter
```

## Usage

```python
from word_text_counter import count_words

file_path = "data/test.txt" #a path to your text file
counts = count_words(file_path)
```

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`word_text_counter` was created by Sumbono. It is licensed under the terms of the MIT license.

## Credits

`word_text_counter` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
